%define with_maven 1
Name:          howl-logger
Version:       1.0.2
Release:       %mkrel 1
Summary:       HOWL - High-speed ObjectWeb Logger
Group:         Development/Java
License:       ASL, BSD
Url:           http://howl.ow2.org/
# svn export svn://svn.forge.objectweb.org/svnroot/howl/tags/HOWL_1_0_2/howl/logger/ howl-logger-1.0.2
# tar czf howl-logger-1.0.2-src-svn.tar.gz howl-logger-1.0.2
Source0:       howl-logger-%{version}-src-svn.tar.gz
Source1:       howl-logger-%{version}-settings.xml
Source2:       howl-logger-%{version}-jpp-depmap.xml
BuildRequires: java-devel
BuildRequires: jpackage-utils
%if !%with_maven
BuildRequires: ant
BuildRequires: ant-junit
BuildRequires: ant-nodeps
BuildRequires: ant-trax
BuildRequires: emma
BuildRequires: junit
%else
BuildRequires: maven
BuildRequires: maven-antrun-plugin
BuildRequires: maven-assembly-plugin
BuildRequires: maven-compiler-plugin
BuildRequires: maven-dependency-plugin
BuildRequires: maven-idea-plugin
BuildRequires: maven-install-plugin
BuildRequires: maven-jar-plugin
BuildRequires: maven-javadoc-plugin
BuildRequires: maven-plugin-plugin
BuildRequires: maven-project-info-reports-plugin
BuildRequires: maven-release-plugin
BuildRequires: maven-remote-resources-plugin
BuildRequires: maven-resources-plugin
BuildRequires: maven-site-plugin
BuildRequires: maven-surefire-plugin
%endif
Requires:      jpackage-utils
BuildArch:     noarch

%description
HOWL is a logger implementation providing features
required by the ObjectWeb JOTM project, with a public
API that is generally usable by any Transaction Manager.
HOWL uses unformatted binary logs to maximize performance
and specifies a journalization API with methods necessary
to support JOTM recovery operations.

%package javadoc
Group:          Development/Java
Summary:        Javadoc for %{name}

%description javadoc
HOWL - High-speed ObjectWeb Logger.

This package contains Javadoc for %{name}.

%prep
%setup -q -n howl-logger-%{version}

chmod -R go=u-w *

for f in $(find . -name "*.jar"); do
  mv $f $f.no
done

%if %with_maven
  cp %{SOURCE1} settings.xml
  sed -i -e "s|<url>__JPP_URL_PLACEHOLDER__</url>|<url>file://`pwd`/.m2/repository</url>|g" settings.xml
  sed -i -e "s|<url>__JAVADIR_PLACEHOLDER__</url>|<url>file://`pwd`/external_repo</url>|g" settings.xml
  sed -i -e "s|<url>__MAVENREPO_DIR_PLACEHOLDER__</url>|<url>file://`pwd`/.m2/repository</url>|g" settings.xml
  sed -i -e "s|<url>__MAVENDIR_PLUGIN_PLACEHOLDER__</url>|<url>file:///usr/share/maven2/plugins</url>|g" settings.xml
%endif

sed -i -e "s|<version>1.0.1-1</version>|<version>%{version}</version>|g" pom.xml

%build

%if %with_maven
  export MAVEN_REPO_LOCAL=$(pwd)/.m2/repository

  mkdir external_repo
  ln -s %{_javadir} external_repo/JPP
  export SETTINGS=$(pwd)/settings.xml
  export MAVEN_OPTS="-Xmx128m"

  mvn-jpp \
    -e \
    -s $SETTINGS \
    -Dmaven2.jpp.depmap.file=%{SOURCE2} \
    -Dmaven.repo.local=$MAVEN_REPO_LOCAL \
    -Dmaven.test.skip=true \
    install javadoc:javadoc
%else
  export CLASSPATH=$(build-classpath emma junit ant/ant-nodeps ant/ant-junit ant/ant-trax)
  ant compile-all all-docs
%endif

%install
mkdir -p %{buildroot}%{_javadir}
%if %with_maven
  install -m 644 target/howl-%{version}.jar \
    %{buildroot}%{_javadir}/howl-logger-%{version}.jar
%else
  install -m 644 bin/howl.jar \
    %{buildroot}%{_javadir}/howl-logger-%{version}.jar
  install -m 644 bin/howl-test.jar \
    %{buildroot}%{_javadir}/howl-logger-test-%{version}.jar
%endif

mkdir -p %{buildroot}%{_mavenpomdir}
install -m 644 pom.xml %{buildroot}%{_mavenpomdir}/JPP-howl-logger.pom
%add_to_maven_depmap org.objectweb.howl howl %{version} JPP howl-logger

(
  cd %{buildroot}%{_javadir}
  for jar in *-%{version}*; do
    ln -sf ${jar} `echo $jar| sed  "s|-%{version}||g"`
  done
)

mkdir -p %{buildroot}%{_javadocdir}/howl-logger-%{version}
%if %with_maven
  cp -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/howl-logger-%{version}
%else
  cp -pr doc/jdoc/project/* %{buildroot}%{_javadocdir}/howl-logger-%{version}
  mkdir -p %{buildroot}%{_javadocdir}/howl-logger-%{version}/public
  cp -pr doc/jdoc/public/* %{buildroot}%{_javadocdir}/howl-logger-%{version}/public
%endif
ln -s howl-logger-%{version} %{buildroot}%{_javadocdir}/howl-logger

%post
%update_maven_depmap

%postun
%update_maven_depmap

%files
%{_javadir}/howl-logger-%{version}.jar
%{_javadir}/howl-logger.jar
%if !%with_maven
%{_javadir}/howl-logger-test-%{version}.jar
%{_javadir}/howl-logger-test.jar
%endif
%{_mavenpomdir}/*
%{_mavendepmapfragdir}/*
%doc LICENSE.txt

%files javadoc
%{_javadocdir}/howl-logger-%{version}
%{_javadocdir}/howl-logger



%changelog

* Tue Oct 18 2011 gil <gil> 1.0.2-1.mga2
+ Revision: 156312
- imported package howl-logger


* Sat Jun 25 2011 gil <gil> 1.0.2-0.%%mkrel
- initial rpm